@@ -40,7 +40,7 @@ from qiskit_ibm_runtime import (  # pylint: disable=unused-import,cyclic-import
     qiskit_runtime_service,
 )
 
-from .api.clients import AccountClient, RuntimeClient
+from .api.clients import RuntimeClient
 from .api.clients.backend import BaseBackendClient
 from .exceptions import IBMBackendApiProtocolError
 from .utils.backend_converter import (
@@ -155,6 +155,7 @@ class IBMBackend(Backend):
         configuration: Union[QasmBackendConfiguration, PulseBackendConfiguration],
         service: "qiskit_runtime_service.QiskitRuntimeService",
         api_client: BaseBackendClient,
+        instance: Optional[str] = None,
     ) -> None:
         """IBMBackend constructor.
 
@@ -168,6 +169,7 @@ class IBMBackend(Backend):
             online_date=configuration.online_date,
             backend_version=configuration.backend_version,
         )
+        self._instance = instance
         self._service = service
         self._api_client = api_client
         self._configuration = configuration
@@ -212,10 +214,14 @@ class IBMBackend(Backend):
                 )
             )
 
-    def _get_properties(self) -> None:
+    def _get_properties(self, datetime: Optional[python_datetime] = None) -> None:
         """Gets backend properties and decodes it"""
+        if datetime:
+            datetime = local_to_utc(datetime)
         if not self._properties:
-            api_properties = self._api_client.backend_properties(self.name)
+            api_properties = self._api_client.backend_properties(
+                self.name, datetime=datetime
+            )
             if api_properties:
                 backend_properties = properties_from_server_data(api_properties)
                 self._properties = backend_properties
@@ -311,6 +317,16 @@ class IBMBackend(Backend):
         self._convert_to_target()
         return self._target
 
+    def target_history(self, datetime: Optional[python_datetime] = None) -> Target:
+        """A :class:`qiskit.transpiler.Target` object for the backend.
+        Returns:
+            Target with properties found on `datetime`
+        """
+        self._get_properties(datetime=datetime)
+        self._get_defaults()
+        self._convert_to_target()
+        return self._target
+
     def properties(
         self, refresh: bool = False, datetime: Optional[python_datetime] = None
     ) -> Optional[BackendProperties]:
@@ -494,7 +510,7 @@ class IBMRetiredBackend(IBMBackend):
         self,
         configuration: Union[QasmBackendConfiguration, PulseBackendConfiguration],
         service: "qiskit_runtime_service.QiskitRuntimeService",
-        api_client: Optional[AccountClient] = None,
+        api_client: Optional[RuntimeClient] = None,
     ) -> None:
         """IBMRetiredBackend constructor.
 
@@ -535,7 +551,7 @@ class IBMRetiredBackend(IBMBackend):
     def from_name(
         cls,
         backend_name: str,
-        api: Optional[AccountClient] = None,
+        api: Optional[RuntimeClient] = None,
     ) -> "IBMRetiredBackend":
         """Return a retired backend from its name."""
         configuration = QasmBackendConfiguration(
