@@ -14,11 +14,12 @@
 
 from unittest import SkipTest
 
+
 from qiskit.transpiler.target import Target
 from qiskit_ibm_runtime import QiskitRuntimeService
 
 from ..ibm_test_case import IBMIntegrationTestCase
-from ..decorators import run_integration_test
+from ..decorators import run_integration_test, production_only
 
 
 class TestIntegrationBackend(IBMIntegrationTestCase):
@@ -67,6 +68,7 @@ class TestIBMBackend(IBMIntegrationTestCase):
         with self.subTest(backend=backend.name):
             self.assertIsInstance(backend.service, QiskitRuntimeService)
 
+    @production_only
     def test_backend_target(self):
         """Check if the target property is set."""
         backend = self.backend
@@ -80,6 +82,7 @@ class TestIBMBackend(IBMIntegrationTestCase):
         with self.subTest(backend=backend.name):
             self.assertIsNotNone(backend.max_circuits)
 
+    @production_only
     def test_backend_qubit_properties(self):
         """Check if the qubit properties are set."""
         backend = self.backend
@@ -101,6 +104,7 @@ class TestIBMBackend(IBMIntegrationTestCase):
         with self.subTest(backend=backend.name):
             self.assertTrue(backend.status().operational)
 
+    @production_only
     def test_backend_properties(self):
         """Check the properties of calibration of a real chip."""
         backend = self.backend
@@ -109,6 +113,7 @@ class TestIBMBackend(IBMIntegrationTestCase):
                 raise SkipTest("Skip since simulator does not have properties.")
             self.assertIsNotNone(backend.properties())
 
+    @production_only
     def test_backend_pulse_defaults(self):
         """Check the backend pulse defaults of each backend."""
         backend = self.backend
@@ -125,6 +130,7 @@ class TestIBMBackend(IBMIntegrationTestCase):
         with self.subTest(backend=backend.name):
             self.assertIsNotNone(backend.configuration())
 
+    @production_only
     def test_backend_invalid_attribute(self):
         """Check if AttributeError is raised when an invalid backend attribute is accessed."""
         backend = self.backend
