@@ -27,7 +27,7 @@ from qiskit_ibm_runtime.exceptions import (
     RuntimeJobMaxTimeoutError,
 )
 from ..ibm_test_case import IBMIntegrationJobTestCase
-from ..decorators import run_integration_test
+from ..decorators import run_integration_test, production_only
 from ..serialization import (
     get_complex_types,
     SerializableClassDecoder,
@@ -87,10 +87,9 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
         """Test a failed program execution."""
         job = self._run_program(service, inputs={})
         job.wait_for_final_state()
-        job_result_raw = service._api_client.job_results(job.job_id())
         self.assertEqual(JobStatus.ERROR, job.status())
         self.assertIn(
-            API_TO_JOB_ERROR_MESSAGE["FAILED"].format(job.job_id(), job_result_raw),
+            API_TO_JOB_ERROR_MESSAGE["FAILED"].format(job.job_id(), ""),
             job.error_message(),
         )
         with self.assertRaises(RuntimeJobFailureError):
@@ -143,6 +142,7 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
             self._run_program(service, max_execution_time=299)
 
     @run_integration_test
+    @production_only
     def test_cancel_job_queued(self, service):
         """Test canceling a queued job."""
         real_device = get_real_device(service)
@@ -187,6 +187,7 @@ class TestIntegrationJob(IBMIntegrationJobTestCase):
                     service.job(job.job_id())
 
     @run_integration_test
+    @production_only
     def test_delete_job_queued(self, service):
         """Test deleting a queued job."""
         real_device = get_real_device(service)
