@@ -19,7 +19,7 @@ from qiskit.primitives import EstimatorResult, SamplerResult
 
 from qiskit_ibm_runtime import Estimator, Session, Sampler, Options
 
-from ..decorators import run_integration_test
+from ..decorators import run_integration_test, quantum_only
 from ..ibm_test_case import IBMIntegrationTestCase
 
 
@@ -72,3 +72,15 @@ class TestIntegrationSession(IBMIntegrationTestCase):
             self.assertAlmostEqual(result.quasi_dists[0][3], 0.5, delta=0.1)
             self.assertAlmostEqual(result.quasi_dists[0][0], 0.5, delta=0.1)
             session.close()
+
+    @run_integration_test
+    @quantum_only
+    def test_using_correct_instance(self, service):
+        """Test the instance used when filtering backends is honored."""
+        instance = self.dependencies.instance
+        backend = service.backend("ibmq_qasm_simulator", instance=instance)
+        with Session(service, backend=backend) as session:
+            sampler = Sampler(session=session)
+            job = sampler.run(ReferenceCircuits.bell(), shots=400)
+            self.assertEqual(instance, backend._instance)
+            self.assertEqual(instance, job.backend()._instance)
